@@ -14,16 +14,18 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from .dataset import Dataset, Modifier, Sampler, T, Wrapper, Iterator
+from .dataset import Dataset, Modifier, Sampler, T, Wrapper, Iterator, SizedDataset
 
 from .apply_modifier import ApplyModifier
 from .bruteforce_cacher import BruteforceCacher
 from .sequential_cacher import SequentialCacher
+from .composer import Composer
 from .concatenator import Concatenator
 from .cyclic_sampler import CyclicSampler
 from .random_sampler import RandomSampler
 from .pickler import Pickler
 from .folder_dataset import FolderDataset
 from .range_sampler import RangeSampler
+from .version_assigner import VersionAssigner
 
 from .utils import split
