@@ -28,6 +28,6 @@ class CyclicSampler(Sampler):
     >>> ds = CyclicSampler(ds, 7)
     >>> assert [item for item in ds] == [1, 2, 3, 1, 2, 3, 1]
     """
-    def __getitem__(self, index) -> T:
+    def __getitem__(self, index: int) -> T:
         internal_index = index % len(self._dataset)
         return self._dataset[internal_index]
