@@ -1,11 +1,28 @@
+"""
+Copyright 2022 Ilia Moiseev
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+   http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+"""
+
 import os
 
-from typing import List, Dict
+from typing import Any
 from hashlib import md5
-from .dataset import Dataset, T
+from ..base import Meta
+from .dataset import SizedDataset, T
 
 
-class FolderDataset(Dataset):
+class FolderDataset(SizedDataset):
     """
     Basic "folder of files" dataset. Accepts root folder in which considers all files.
     Is abstract - getitem is not defined, since it is specific for each file type.
@@ -14,12 +31,12 @@ class FolderDataset(Dataset):
     --------
     cascade.utils.FolderImageDataset
     """
-    def __init__(self, root: str, *args, **kwargs) -> None:
+    def __init__(self, root: str, *args: Any, **kwargs: Any) -> None:
         """
         Parameters
         ----------
         root: str
-            A path to the folder of files 
+            A path to the folder of files
         """
         super().__init__(*args, **kwargs)
         self._root = os.path.abspath(root)
@@ -28,10 +45,10 @@ class FolderDataset(Dataset):
         self._names = [os.path.join(self._root, name)
                        for name in sorted(os.listdir(self._root)) if not os.path.isdir(name)]
 
-    def __getitem__(self, item) -> T:
+    def __getitem__(self, item: int) -> T:
         raise NotImplementedError()
 
-    def get_meta(self) -> List[Dict]:
+    def get_meta(self) -> Meta:
         meta = super().get_meta()
         meta[0].update({
             'name': repr(self),
