@@ -14,8 +14,8 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-
-from . import T, Dataset, Sampler
+from typing import Any, Union
+from . import T, SizedDataset, Sampler
 
 
 class RangeSampler(Sampler):
@@ -42,31 +42,52 @@ class RangeSampler(Sampler):
     2
     3
     """
-    def __init__(self,
-        dataset: Dataset,
-        start:int = None,
-        stop:int = None,
-        step:int = 1,
-        *args, **kwargs) -> None:
+    def __init__(
+            self,
+            dataset: SizedDataset[T],
+            start: Union[int, None] = None,
+            stop: Union[int, None] = None,
+            step: Union[int, None] = 1,
+            *args: Any, **kwargs: Any) -> None:
         """
         Parameters
         ----------
-            dataset: Dataset
-                A dataset to sampler from
+            dataset: SizedDataset
+                A dataset to sample from
             start: int
                 Start index in range - included
             stop: int
                 Stop index in range - excluded
             step: int, optional
                 Step of range
+        Raises
+        ------
+        ValueError: when no start or stop present or
+        when parameters given produce empty dataset
         """
+
+        # Check if can build range
+        if start is None and stop is None:
+            raise ValueError(
+                f"Either start or stop must be present\
+                Got start = {start}, stop = {stop}"
+            )
+
+        # Check if only stop was passed
         if start is not None and stop is None:
             stop = start
             start = 0
 
         self._indices = [i for i in range(start, stop, step)]
+
+        if len(self._indices) == 0:
+            raise ValueError(
+                f'Given combination of start, stop and step'
+                f'produced empty dataset. Got start = {start}, stop = {stop}, step = {step}'
+            )
+
         super().__init__(dataset, len(self._indices), *args, **kwargs)
 
-    def __getitem__(self, index) -> T:
+    def __getitem__(self, index: int) -> T:
         internal_index = self._indices[index]
         return super().__getitem__(internal_index)
