@@ -14,9 +14,8 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import os
-import warnings
-from typing import List
+from typing import List, Union, Dict, Any
+
 import pendulum
 import pandas as pd
 from flatten_json import flatten
@@ -25,9 +24,8 @@ import plotly
 from plotly import express as px
 from plotly import graph_objects as go
 
+from ..models import ModelRepo
 from . import MetaViewer
-from .. import __version__
-from ..data import Dataset
 
 
 class HistoryViewer:
@@ -37,10 +35,10 @@ class HistoryViewer:
     models with different hyperparameters depend on each other.
     """
     def __init__(
-        self,
-        repo,
-        last_lines: int = None,
-        last_models: int = None) -> None:
+            self,
+            repo: ModelRepo,
+            last_lines: Union[int, None] = None,
+            last_models: Union[int, None] = None) -> None:
         """
         Parameters
         ----------
@@ -56,27 +54,23 @@ class HistoryViewer:
         self._last_models = last_models
         self._make_table()
 
-    def _make_table(self):
+    def _make_table(self) -> None:
         metas = []
-        self._params = []
-        for line in [*self._repo][::-1][:self._last_lines]:
-            # Try to use viewer only on models using type key
-            try:
-                view = MetaViewer(line.root, filt={'type': 'model'})
-            except KeyError:
-                view = [MetaViewer(os.path.join(
-                    line.root,
-                    os.path.dirname(model_name)))[0]
-                    for model_name in line.model_names]
+        params = []
 
-                warnings.warn(f'''You use cascade {__version__} with the repo generated in version <= 0.4.1 without
-                type key in some of the meta files (in repo, line or model).
-                Consider updating your repo's meta by opening it with ModelRepo constructor in new version or manually.
-                In the following versions it will be deprecated.''', FutureWarning)
+        line_names = self._repo.get_line_names()
+        if self._last_lines is not None:
+            # Takes last N lines in correct order
+            line_names = line_names[-self._last_lines:]
+
+        for line_name in line_names:
+            line = self._repo[line_name]
+            view = MetaViewer(line.root, filt={'type': 'model'})
 
             for i in range(len(line))[:self._last_models]:
                 new_meta = {'line': line.root, 'num': i}
                 try:
+                    # TODO: to take only first is not good...
                     meta = view[i][0]
                 except IndexError:
                     meta = {}
@@ -84,20 +78,21 @@ class HistoryViewer:
                 new_meta.update(flatten(meta))
                 metas.append(new_meta)
 
-                params = {
+                p = {
                     'line': line.root,
                 }
                 if 'params' in meta:
                     if len(meta['params']) > 0:
-                        params.update(flatten({'params': meta['params']}))
-                self._params.append(params)
+                        p.update(flatten({'params': meta['params']}))
+                params.append(p)
 
         self._table = pd.DataFrame(metas)
+        self._params = params
         if 'saved_at' in self._table:
             self._table = self._table.sort_values('saved_at')
 
     @staticmethod
-    def _diff(p1, params) -> List:
+    def _diff(p1: Dict[Any, Any], params: Dict[Any, Any]) -> List:
         diff = [DeepDiff(p1, p2) for p2 in params]
         changed = [0 for _ in range(len(params))]
         for i in range(len(changed)):
@@ -204,10 +199,10 @@ class HistoryViewer:
 
         return fig
 
-    def serve(self, metric: str, **kwargs):
+    def serve(self, metric: str, **kwargs: Any) -> None:
         """
         Run dash-based server with HistoryViewer, updating plots in real-time.
-        
+
         Note
         ----
         This feature needs `dash` to be installed.
