@@ -11,7 +11,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from typing import Callable, Union, List
+from typing import Callable, Union, List, NoReturn, Dict, Any
 from tqdm import tqdm
 
 from ..data import Dataset, Modifier, T
@@ -23,13 +23,20 @@ class DataValidationException(Exception):
     """
 
 
+def prettify_items(items: List[int]) -> str:
+    if len(items) < 20:
+        return str(items)
+    else:
+        return f'{", ".join(map(str, items[:5]))} ... {", ".join(map(str, items[-5:]))}'
+
+
 class Validator(Modifier):
     """
     Base class for validators. Defines basic `__init__` structure
     """
-    def __init__(self, dataset: Dataset,
+    def __init__(self, dataset: Dataset[T],
                  func: Union[Callable[[T], bool], List[Callable[[T], bool]]],
-                 **kwargs) -> None:
+                 **kwargs: Any) -> None:
         super().__init__(dataset, **kwargs)
         if isinstance(func, Callable):
             self._func = [func]
@@ -48,7 +55,7 @@ class AggregateValidator(Validator):
     >>> ds = Wrapper([1, 2, 3, 4, 5])
     >>> ds = AggregateValidator(ds, lambda x: len(x) == 5)
     """
-    def __init__(self, dataset: Dataset, func: Callable[[Dataset], bool], **kwargs) -> None:
+    def __init__(self, dataset: Dataset[T], func: Callable[[Dataset[T]], bool], **kwargs) -> None:
         super().__init__(dataset, func, **kwargs)
 
         bad_results = []
@@ -77,7 +84,7 @@ class PredicateValidator(Validator):
             self,
             dataset: Dataset,
             func: Union[Callable[[T], bool], List[Callable[[T], bool]]],
-            **kwargs) -> None:
+            **kwargs: Any) -> None:
         super().__init__(dataset, func, **kwargs)
 
         bad_items = {j: [] for j in range(len(self._func))}
@@ -92,18 +99,11 @@ class PredicateValidator(Validator):
         else:
             print('OK!')
 
-    @staticmethod
-    def _prettify_items(items: List[int]) -> str:
-        if len(items) < 20:
-            return str(items)
-        else:
-            return f'{", ".join(map(str, items[:5]))} ... {", ".join(map(str, items[-5:]))}'
-
-    def _raise(self, items: List[int]):
+    def _raise(self, items: Dict[int, List[int]]) -> NoReturn:
         bad_counts = [len(items[i]) for i in range(len(self._func))]
 
         failed_checks = [i for i in range(len(bad_counts)) if bad_counts[i]]
-        failed_items = '\n'.join([f'{i}: {self._prettify_items(items[i])}' for i in items])
+        failed_items = '\n'.join([f'{i}: {prettify_items(items[i])}' for i in items])
         raise DataValidationException(
             f'Checks in positions {failed_checks} failed\n'
             f'Items failed by check:\n'
