@@ -15,10 +15,10 @@ limitations under the License.
 """
 
 import warnings
-from typing import List, Dict
+from typing import List, Dict, Any, Union
 import pendulum
 
-from ..base import Traceable
+from ..base import Traceable, Meta
 
 
 class Model(Traceable):
@@ -26,55 +26,56 @@ class Model(Traceable):
     Base class for any model.
     Used to provide unified interface to any model, store metadata including metrics.
     """
-    def __init__(self, *args, meta_prefix=None, **kwargs) -> None:
+    def __init__(self, *args: Any,
+                 meta_prefix: Union[Meta, str, None] = None, **kwargs: Any) -> None:
         """
         Should be called in any successor - initializes default meta needed.
         Arguments passed in it should be related to model's hyperparameters, architecture.
         All additional arguments should have defaults - to be able to create model and then load.
         Successors may pass all of their parameters to superclass for it to be able to
-        log them in meta. Everything that is worth to document about model and data it was trained on can be
-        either in params or meta_prefix.
+        log them in meta. Everything that is worth to document about model and data 
+        it was trained on can be either in params or meta_prefix.
         """
         # Model accepts meta_prefix explicitly to not to record it in 'params'
         self.metrics = {}
         self.params = kwargs
         self.created_at = pendulum.now(tz='UTC')
-        super().__init__(meta_prefix=meta_prefix, **kwargs)
+        super().__init__(*args, meta_prefix=meta_prefix, **kwargs)
 
-    def fit(self, *args, **kwargs) -> None:
+    def fit(self, *args: Any, **kwargs: Any) -> None:
         """
         Method to encapsulate training loops.
         May be provided with any training-related arguments.
         """
         raise NotImplementedError()
 
-    def predict(self, *args, **kwargs):
+    def predict(self, *args: Any, **kwargs: Any) -> Any:
         """
         Method to encapsulate inference.
         May include preprocessing steps to make model self-sufficient.
         """
         raise NotImplementedError()
 
-    def evaluate(self, *args, **kwargs) -> None:
+    def evaluate(self, *args: Any, **kwargs: Any) -> None:
         """
         Evaluates model against any metrics. Should not return any value, just populate self.metrics dict.
         """
         raise NotImplementedError()
 
-    def load(self, filepath, *args, **kwargs) -> None:
+    def load(self, filepath: str, *args: Any, **kwargs: Any) -> None:
         """
         Loads model from provided filepath. May be unpickling process or reading json configs.
         Does not return any model, just restores internal state.
         """
         raise NotImplementedError()
 
-    def save(self, filepath, *args, **kwargs) -> None:
+    def save(self, filepath: str, *args: Any, **kwargs: Any) -> None:
         """
         Saves model's state using provided filepath.
         """
         raise NotImplementedError()
 
-    def get_meta(self) -> List[Dict]:
+    def get_meta(self) -> Meta:
         # Successors may not call super().__init__
         # they may not have these default fields
 
@@ -97,7 +98,9 @@ class Model(Traceable):
             all_default_exist = False
 
         if not all_default_exist:
-            warnings.warn('Model\'s meta is incomplete, maybe you haven\'t call super().__init__ in subclass?')
+            warnings.warn(
+                'Model\'s meta is incomplete, '
+                'maybe you haven\'t call super().__init__ in subclass?')
 
         meta[0]['type'] = 'model'
         return meta
@@ -108,7 +111,7 @@ class ModelModifier(Model):
     Analog of dataset's Modifier. Can be used to chain
     two models in one.
     """
-    def __init__(self, model: Model, **kwargs):
+    def __init__(self, model: Model, *args: Any, **kwargs: Any) -> None:
         """
         Parameters
         ----------
@@ -116,8 +119,8 @@ class ModelModifier(Model):
             A model to modify.
         """
         self._model = model
-        super().__init__(**kwargs)
+        super().__init__(*args, **kwargs)
 
-    def get_meta(self) -> List[Dict]:
+    def get_meta(self) -> Meta:
         prev_meta = self._model.get_meta()
         return super().get_meta() + prev_meta
