@@ -11,19 +11,19 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
+import os
 import warnings
 import itertools
-import os
 import logging
-from typing import List, Dict, Iterable
+from typing import List, Iterable, Union, Any, Literal, Type, Generator
 import shutil
 
 import pendulum
 from deepdiff.diff import DeepDiff
 
-from ..base import Traceable, supported_meta_formats
+from ..base import Traceable, MetaHandler, JSONEncoder, supported_meta_formats, Meta
+from .model import Model
 from .model_line import ModelLine
-from ..meta import MetaViewer
 
 
 class Repo(Traceable):
@@ -36,13 +36,13 @@ class Repo(Traceable):
     """
     root = None
 
-    def reload(self):
+    def reload(self) -> None:
         raise NotImplementedError()
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> ModelLine:
         raise NotImplementedError()
 
-    def __len__(self):
+    def __len__(self) -> int:
         raise NotImplementedError()
 
 
@@ -57,51 +57,62 @@ class ModelRepo(Repo):
     Example
     -------
     >>> from cascade.models import ModelRepo
-    >>> from cascade.utils import ConstantBaseline
-    >>> repo = ModelRepo('repo', _meta_prefix={'description': 'This is a repo with one VGG16 line for the example.'})
-    >>> line = repo.add_line('model', ConstantBaseline)
-    >>> model = ConstantBaseline(1)
+    >>> from cascade import utils as cdu
+    >>> repo = ModelRepo('repo', meta_prefix={'description': 'This is a repo with one line for the example.'})
+    >>> line = repo.add_line('model', cdu.ConstantBaseline)
+    >>> model = cdu.ConstantBaseline(1)
     >>> model.fit()
     >>> line.save(model)
 
 
     >>> from cascade.models import ModelRepo
-    >>> from cascade.utils import ConstantBaseline
-    >>> repo = ModelRepo('repo', lines=[dict(name='constant', model_cls=ConstantBaseline)])
-    >>> model = ConstantBaseline()
+    >>> from cascade import utils as cdu
+    >>> repo = ModelRepo('repo', lines=[dict(name='constant', model_cls=cdu.ConstantBaseline)])
+    >>> model = cdu.ConstantBaseline()
     >>> model.fit()
     >>> repo['constant'].save(model)
     """
-    def __init__(self, folder, lines:List[Dict] = None,
-                 overwrite:bool = False, meta_fmt:str = '.json', **kwargs):
+    def __init__(
+        self,
+        folder: str,
+        lines: Union[Iterable[ModelLine], None] = None,
+        overwrite: bool = False,
+        meta_fmt: Literal['.json', '.yml'] = '.json',
+        model_cls: Type = Model, **kwargs: Any) -> None:
         """
         Parameters
         ----------
         folder:
-            Path to a folder where ModelRepo needs to be created or already was created.
-            If folder does not exist, creates it automatically.
-        lines: List[Dict], optional
-            A list with parameters of model lines to add at creation or to initialize (alias for `add_model`).
-        overwrite: bool, optional
-            If True will remove folder that is passed in first argument and start a new repo in that place.
-        meta_fmt: str, optional
-            Extension of repo's metadata files and that will be assigned to the lines by default.
+            Path to a folder where ModelRepo needs to be created or already was created
+            if folder does not exist, creates it
+        lines: List[Dict]
+            A list with parameters of model lines to add at creation or to initialize (alias for `add_model`)
+        overwrite: bool
+            if True will remove folder that is passed in first argument and start a new repo
+            in that place
+        meta_fmt: str
+            extension of repo's metadata files and that will be assigned to the lines by default
+            `.json` and `.yml` are supported
+        model_cls:
+            Default class for any ModelLine in repo
         See also
         --------
         cascade.models.ModelLine
         """
         super().__init__(**kwargs)
+        self._model_cls = model_cls
         self._root = folder
-        self.lines = dict()
+        self._lines = dict()
 
-        assert meta_fmt in supported_meta_formats, f'Only {supported_meta_formats} are supported formats'
+        assert meta_fmt in supported_meta_formats, \
+            f'Only {supported_meta_formats} are supported formats'
         self._meta_fmt = meta_fmt
         if overwrite and os.path.exists(self._root):
             shutil.rmtree(self._root)
 
         os.makedirs(self._root, exist_ok=True)
-        # Can create MeV only if path already exists
-        self._mev = MetaViewer(self._root)
+
+        self._mh = MetaHandler()
         self._load_lines()
         self._setup_logger()
 
@@ -111,14 +122,16 @@ class ModelRepo(Repo):
 
         self._update_meta()
 
-    def _load_lines(self):
-        self.lines = {name: ModelLine(os.path.join(self._root, name),
-                                      meta_prefix=self._meta_prefix,
-                                      meta_fmt=self._meta_fmt)
-                      for name in sorted(os.listdir(self._root))
-                      if os.path.isdir(os.path.join(self._root, name))}
+    def _load_lines(self) -> None:
+        self._lines = {
+            name: ModelLine(os.path.join(self._root, name),
+                            model_cls=self._model_cls,
+                            meta_prefix=self._meta_prefix,
+                            meta_fmt=self._meta_fmt)
+            for name in sorted(os.listdir(self._root))
+            if os.path.isdir(os.path.join(self._root, name))}
 
-    def add_line(self, name, *args, meta_fmt=None, **kwargs):
+    def add_line(self, name: str = None, *args, meta_fmt=None, **kwargs) -> ModelLine:
         """
         Adds new line to repo if it doesn't exist and returns it.
         If line exists, defines it in repo with parameters provided.
@@ -126,15 +139,28 @@ class ModelRepo(Repo):
         Supports all the parameters of ModelLine using args and kwargs.
 
         Parameters:
-        name: str
-            Name of the line. It is used to name a folder of line.
-            Repo prepends it with `self._root` before creating.
-        meta_fmt: str
-            Format of meta files. If omitted, inherits format from repo.
+            name: str, optional
+                Name of the line. It is used to name a folder of line.
+                Repo prepends it with `self._root` before creating.
+                Optional argument. If omitted - names new line automatically
+                using f'{len(self):0>5d}'
+            meta_fmt: str, optional
+                Format of meta files. Supported values are the same as for repo.
+                If omitted, inherits format from repo.
         See also
         --------
             cascade.models.ModelLine
        """
+        # TODO: use default model_cls
+        if name is None:
+            name = f'{len(self):0>5d}'
+            if name in self.get_line_names():
+                # Name can appear in the repo if the user manually
+                # removed the lines from the middle of the repo
+
+                # This will be handled strictly
+                # until it will become clear that some solution needed
+                raise RuntimeError(f'Line {name} already exists in {self}')
 
         folder = os.path.join(self._root, name)
         if meta_fmt is None:
@@ -144,22 +170,27 @@ class ModelRepo(Repo):
                          meta_prefix=self._meta_prefix,
                          meta_fmt=meta_fmt,
                          **kwargs)
-        self.lines[name] = line
+        self._lines[name] = line
 
         self._update_meta()
         return line
 
-    def __getitem__(self, key) -> ModelLine:
+    def __getitem__(self, key: Union[str, int]) -> ModelLine:
         """
         Returns
         -------
         line: ModelLine
            existing line of the name passed in `key`
         """
-        return self.lines[key]
+        if isinstance(key, str):
+            return self._lines[key]
+        elif isinstance(key, int):
+            return self._lines[list(self._lines.keys())[key]]
+        else:
+            raise TypeError(f'{type(key)} is not supported as key')
 
-    def __iter__(self):
-        for line in self.lines:
+    def __iter__(self) -> Generator[ModelLine, None, None]:
+        for line in self._lines:
             yield self.__getitem__(line)
 
     def __len__(self) -> int:
@@ -169,19 +200,19 @@ class ModelRepo(Repo):
         num: int
             a number of lines
         """
-        return len(self.lines)
+        return len(self._lines)
 
     def __repr__(self) -> str:
         return f'ModelRepo in {self._root} of {len(self)} lines'
 
-    def _setup_logger(self):
+    def _setup_logger(self) -> None:
         self.logger = logging.getLogger(self._root)
         hdlr = logging.FileHandler(os.path.join(self._root, 'history.log'))
         hdlr.setFormatter(logging.Formatter('\n%(asctime)s\n%(message)s'))
         self.logger.addHandler(hdlr)
         self.logger.setLevel('DEBUG')
 
-    def _update_meta(self):
+    def _update_meta(self) -> None:
         # Reads meta if exists and updates it with new values
         # writes back to disk
         meta_path = os.path.join(self._root, 'meta' + self._meta_fmt)
@@ -189,21 +220,21 @@ class ModelRepo(Repo):
         meta = {}
         if os.path.exists(meta_path):
             try:
-                meta = self._mev.read(meta_path)[0]
+                meta = self._mh.read(meta_path)[0]
             except IOError as e:
                 warnings.warn(f'File reading error ignored: {e}')
 
-        self_meta = self._mev.obj_to_dict(self.get_meta()[0])
+        self_meta = JSONEncoder().obj_to_dict(self.get_meta()[0])
         diff = DeepDiff(meta, self_meta, exclude_paths=["root['name']", "root['updated_at']"])
         self.logger.info(diff.pretty())
 
         meta.update(self.get_meta()[0])
         try:
-            self._mev.write(meta_path, [meta])
+            self._mh.write(meta_path, [meta])
         except IOError as e:
             warnings.warn(f'File writing error ignored: {e}')
 
-    def get_meta(self) -> List[Dict]:
+    def get_meta(self) -> Meta:
         meta = super().get_meta()
         meta[0].update({
             'root': self._root,
@@ -220,7 +251,7 @@ class ModelRepo(Repo):
         self._load_lines()
         self._update_meta()
 
-    def __del__(self):
+    def __del__(self) -> None:
         # Release all files on destruction
         if hasattr(self, 'logger'):
             for handler in self.logger.handlers:
@@ -234,8 +265,7 @@ class ModelRepo(Repo):
         """
         Returns list of line names.
         """
-        # TODO: write test covering this
-        return list(self.lines.keys())
+        return list(self._lines.keys())
 
 
 class ModelRepoConcatenator(Repo):
@@ -244,11 +274,11 @@ class ModelRepoConcatenator(Repo):
     For the ease of use please, don't use it directly.
     Just do `repo = repo_1 + repo_2` to unify two or more repos.
     """
-    def __init__(self, repos: Iterable[Repo], *args, **kwargs) -> None:
+    def __init__(self, repos: Iterable[Repo], *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
         self._repos = repos
 
-    def __getitem__(self, key):
+    def __getitem__(self, key) -> ModelLine:
         pair = key.split('_')
         if len(pair) <= 2:
             raise KeyError(f'Key {key} is not in required format \
@@ -259,20 +289,20 @@ class ModelRepoConcatenator(Repo):
 
         return self._repos[idx][line_name]
 
-    def __len__(self):
+    def __len__(self) -> int:
         return sum([len(repo) for repo in self._repos])
 
-    def __iter__(self):
+    def __iter__(self) -> Generator[ModelLine, None, None]:
         # this flattens the list of lines
         for line in itertools.chain(*[[line for line in repo] for repo in self._repos]):
             yield line
 
-    def __add__(self, repo):
+    def __add__(self, repo: ModelRepo):
         return ModelRepoConcatenator([self, repo])
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f'ModelRepoConcatenator of {len(self._repos)} repos, {len(self)} lines total'
 
-    def reload(self):
+    def reload(self) -> None:
         for repo in self._repos:
             repo.reload()
