@@ -36,10 +36,10 @@ def test_meta():
 
 @pytest.mark.parametrize(
     'arrs', [
-        ([0], [0], [0]),
-        ([1, 2, 3, 4], [11]),
-        ([1],),
-        ([1, 2, 3, 4], [])
+        (Wrapper([0]), Wrapper([0]), Wrapper([0])),
+        (Wrapper([1, 2, 3, 4]), Wrapper([11])),
+        (Wrapper([1]),),
+        (Wrapper([1, 2, 3, 4]), Wrapper([]))
     ]
 )
 def test_concatenation(arrs):
