@@ -15,14 +15,13 @@ limitations under the License.
 """
 
 import os
-# import glob
-# from hashlib import md5
+import glob
+from hashlib import md5
 import pickle
-from typing import Any, Dict, List
-import warnings
+from typing import Any, Dict, List, Union, Any
 from sklearn.pipeline import Pipeline
 
-# from ..base import MetaHandler
+from ..base import MetaHandler, Meta
 from ..models import BasicModel
 
 
@@ -32,7 +31,7 @@ class SkModel(BasicModel):
     Accepts the name and block to form pipeline.
     Can fit, evaluate, predict save and load out of the box.
     """
-    def __init__(self, name=None, blocks=None, **kwargs) -> None:
+    def __init__(self, *args: Any, blocks: Union[List[Any], None]=None, **kwargs: Any) -> None:
         """
         Parameters
         ----------
@@ -41,13 +40,7 @@ class SkModel(BasicModel):
         blocks: list, optional
             List of sklearn transformers to make a pipeline from
         """
-        if name is not None:
-            warnings.warn('''You passed not required argument name.
-            It is deprecated and will be removed in following versions''', FutureWarning)
-            self.name = name
-            super().__init__(name=name, **kwargs)
-        else:
-            super().__init__(**kwargs)
+        super().__init__(*args, **kwargs)
 
         if blocks is not None:
             self._pipeline = self._construct_pipeline(blocks)
@@ -56,48 +49,54 @@ class SkModel(BasicModel):
     def _construct_pipeline(blocks: List[Any]) -> Pipeline:
         return Pipeline([(str(i), block) for i, block in enumerate(blocks)])
 
-    def fit(self, x, y, *args, **kwargs) -> None:
+    def fit(self, x: Any, y: Any, *args: Any, **kwargs: Any) -> None:
         """
         Wrapper for pipeline.fit
         """
         self._pipeline.fit(x, y, *args, **kwargs)
 
-    def predict(self, x, *args, **kwargs):
+    def predict(self, x: Any, *args: Any, **kwargs: Any) -> Any:
         """
         Wrapper for pipeline.predict
         """
         return self._pipeline.predict(x, *args, **kwargs)
 
-    def predict_proba(self, x, *args, **kwargs):
+    def predict_proba(self, x: Any, *args: Any, **kwargs: Any) -> Any:
         """
         Wrapper for pipeline.predict_proba
         """
         return self._pipeline.predict_proba(x, *args, **kwargs)
 
-    # Will be added again when thoroughly tested
-    # def _check_model_hash(self, meta, path_w_ext) -> None:
-    #     with open(path_w_ext, 'rb') as f:
-    #         file_hash = md5(f.read()).hexdigest()
-    #     if file_hash == meta['md5sum']:
-    #         return
-    #     else:
-    #         raise RuntimeError(f'.pkl model hash check failed\n \
-    #              it may be that model\'s .pkl file was corrupted\n \
-    #              hash from meta: {meta["md5sum"]}\n \
-    #              hash from .pkl: {file_hash}')
+    def _check_model_hash(self, path: str) -> None:
+        root = os.path.dirname(path)
+        names = glob.glob(os.path.join(f'{root}', 'meta.*'))
+        if len(names) == 1:
+            meta = MetaHandler().read(names[0])
+            # Uses first meta in list
+            # Usually the list is of unit length
+            meta = meta[0]
+            if 'md5sum' in meta:
+                with open(path, 'rb') as f:
+                    file_hash = md5(f.read()).hexdigest()
+                if file_hash != meta['md5sum']:
+                    raise RuntimeError(
+                        f'.pkl model hash check failed '
+                        f'it may be that model\'s .pkl file was corrupted\n'
+                        f'hash from {names[0]}: {meta["md5sum"]}\n'
+                        f'hash of {path}: {file_hash}'
+                    )
+        elif len(names) > 1:
+            raise RuntimeError(f'Multiple possible meta-files found: {names}')
 
-    def load(self, path: str) -> None:
+    def load(self, path: str, check_hash: bool = True) -> None:
         """
         Loads the model from path provided. If no extension, .pkl is added.
         """
         if os.path.splitext(path)[-1] != '.pkl':
             path += '.pkl'
-        # root = os.path.dirname(path)
-        # names = glob.glob(os.path.join(f'{root}', 'meta.json'))
-        # if len(names):
-        #     meta = MetaHandler().read(names[0])
-        #     if 'md5sum' in meta:
-        #         self._check_model_hash(meta, path)
+
+        if check_hash:
+            self._check_model_hash(path)
 
         with open(path, 'rb') as f:
             self._pipeline = pickle.load(f)
@@ -112,7 +111,7 @@ class SkModel(BasicModel):
         with open(f'{path}', 'wb') as f:
             pickle.dump(self._pipeline, f)
 
-    def get_meta(self) -> List[Dict]:
+    def get_meta(self) -> Meta:
         meta = super().get_meta()
         meta[0].update({
             'pipeline': repr(self._pipeline)
